@@ -1,11 +1,11 @@
 `bestlca` <-
-function(patterns,freq,nclass,calcSE,notrials,verbose) {
+function(patterns,freq,nclass,calcSE,notrials,probit,verbose) {
 	bics <- rep(NA,notrials)
 	set.seed(24567)
 	for (i in 1:notrials) {
 		seed <- runif(1)*24674
 		set.seed(seed)		
-		lca <- fit.fixed.randomLCA(patterns,freq,nclass=nclass,calcSE=FALSE,verbose=verbose)
+		lca <- fit.fixed.randomLCA(patterns,freq,nclass=nclass,calcSE=FALSE,probit=probit,verbose=verbose)
 		currbic <- -2*(lca$logLik)+log(lca$nobs)*lca$np
 		bics[i] <- currbic
 		if (i==1) {
@@ -22,7 +22,7 @@ function(patterns,freq,nclass,calcSE,notrials,verbose) {
 	if (calcSE) {
 		if (verbose) print("refitting to obtain SE")
 		maxlca <- fit.fixed.randomLCA(patterns,freq,nclass=nclass,initoutcomep=maxlca$outcomep,
-			initclassp=maxlca$classp,calcSE=TRUE,verbose=verbose)
+			initclassp=maxlca$classp,calcSE=TRUE,probit=probit,verbose=verbose)
 	}
 	if (verbose) {
 		print(maxlca)
